@@ -4,6 +4,7 @@ import webbrowser
 
 from . import pack
 from . import unpack
+from . import models
 from . import helpers
 
 colorama.init(autoreset=True)
@@ -23,7 +24,7 @@ def main():
 
         sys.exit(0)
 
-    if arg[-1].endswith(helpers.FILE_EXTENSION):
+    if arg[-1].endswith(models.FILE_EXTENSION):
         unpack.load(arg[-1])
         print(f'{colorama.Fore.GREEN}BKPK · Unpacking successful!')
     else:
